@@ -192,6 +192,16 @@ class Result(object):
         self.debug(metadata.headers)
         return metadata
 
+    def update(self, request_id=None):
+        if request_id is None:
+            request_id = self.reply['request_id']
+        task_url = '%s/tasks/%s' % (self._url, request_id)
+        self.debug("GET %s", task_url)
+
+        result = self.robust(self.session.get)(task_url, verify=self.verify)
+        result.raise_for_status()
+        self.reply = result.json()
+
     def delete(self):
 
         if self._deleted:
@@ -238,6 +248,7 @@ class Client(object):
                  delete=True,
                  retry_max=500,
                  sleep_max=120,
+                 wait_until_complete=True,
                  info_callback=None,
                  warning_callback=None,
                  error_callback=None,
@@ -287,6 +298,7 @@ class Client(object):
         self.full_stack = full_stack
         self.delete = delete
         self.last_state = None
+        self.wait_until_complete = wait_until_complete
 
         self.debug_callback = debug_callback
         self.warning_callback = warning_callback
@@ -329,11 +341,11 @@ class Client(object):
         result = self._api('%s/tasks/services/%s/clientid-%s' % (self.url, name, uuid.uuid4().hex), request, 'PUT')
         return result
 
-    def workflow(self, code, *args, **kwargs):
+    def workflow(self, code, *args,  workflow_name='application', **kwargs):
         params = dict(code=code,
                       args=args,
                       kwargs=kwargs,
-                      workflow_name='application')
+                      workflow_name=workflow_name)
         return self.service("tool.toolbox.orchestrator.run_workflow", params)
 
     def status(self, context=None):
@@ -411,6 +423,9 @@ class Client(object):
             else:
                 raise
 
+        if not self.wait_until_complete:
+            return Result(self, reply)
+
         sleep = 1
 
         while True:
@@ -548,7 +563,7 @@ class Client(object):
             while tries < self.retry_max:
                 try:
                     r = call(*args, **kwargs)
-                except requests.exceptions.ConnectionError as e:
+                except (requests.exceptions.ConnectionError, requests.exceptions.ReadTimeout) as e:
                     r = None
                     self.warning("Recovering from connection error [%s], attemps %s of %s",
                                  e, tries, self.retry_max)
